/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef SECMEM_H
#define SECMEM_H 1

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "config.h"

#ifdef MINGW32
#include "mingw.h"
#include <windows.h>
#else
#include <sys/mman.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Trashes siz bytes at buf.
 *
 * @param buf - The buffer that should be trashed.
 * @param siz - The number of bytes that should be overidden.
 */
#ifdef MINGW32
EXPORT
#endif
void trash_memory (void *buf, size_t siz);

/**
 * Simple malloc() wrapper.
 * Memory allocated with malloc_secure() must be freed using free_secure().
 */
#ifdef MINGW32
EXPORT
#endif
void * malloc_secure (size_t siz);

/**
 * Simple realloc() wrapper, that trashs all memory before giving 
 * it back to the system.
 *
 * Memory allocated with realloc_secure() must be freed using free_secure(), resp.
 * reallocated using realloc_secure().
 */
#ifdef MINGW32
EXPORT
#endif
void * realloc_secure (void *buf, size_t newsiz);

/**
 * Simple free() wrapper, that trashs all memory before giving it 
 * back to the system.
 * Can only be used to free memory allocated using malloc_secure(), realloc_secure() or
 * strdup_secure().
 */
#ifdef MINGW32
EXPORT
#endif
void free_secure (void *buf);

/**
 * Simple strdup() wrapper.
 *
 * Memory allocated with strdup_secure() must be freed using free_secure(), resp.
 * reallocated using realloc_secure().
 */
#ifdef MINGW32
EXPORT
#endif
char * strdup_secure (char *s);
    
#ifdef __cplusplus
}
#endif

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
